@@ -1487,7 +1487,7 @@ class NewSegmentInputSpec(SPMCommandInputSpec):
         desc="""A tuple with the following fields:
             - bias reguralisation (0-10)
             - FWHM of Gaussian smoothness of bias
-            - which maps to save (Corrected, Field) - a tuple of two boolean values""",
+            - which maps to save (Field, Corrected) - a tuple of two boolean values""",
         field='channel')
     tissues = traits.List(
         traits.Tuple(
@@ -1681,11 +1681,11 @@ class NewSegment(SPMCommand):
 
             if isdefined(self.inputs.channel_info):
                 if self.inputs.channel_info[2][0]:
-                    outputs['bias_corrected_images'].append(
-                        os.path.join(pth, "m%s.nii" % (base)))
-                if self.inputs.channel_info[2][1]:
                     outputs['bias_field_images'].append(
                         os.path.join(pth, "BiasField_%s.nii" % (base)))
+                if self.inputs.channel_info[2][1]:
+                    outputs['bias_corrected_images'].append(
+                        os.path.join(pth, "m%s.nii" % (base)))
         return outputs
 
 
