@@ -32,6 +32,8 @@ from ...utils.filemanip import (md5, FileNotFoundError, ensure_list,
 from ...interfaces.base import (traits, InputMultiPath, CommandLine, Undefined,
                                 DynamicTraitedSpec, Bunch, InterfaceResult,
                                 Interface, isdefined)
+from ...interfaces.base.specs import get_filecopy_info
+
 from .utils import (
     _parameterization_dir, save_hashfile as _save_hashfile, load_resultfile as
     _load_resultfile, save_resultfile as _save_resultfile, nodelist_runner as
@@ -159,7 +161,6 @@ class Node(EngineBase):
         self._got_inputs = False
         self._originputs = None
         self._output_dir = None
-        self._id = self.name  # for compatibility with node expansion using iterables
 
         self.iterables = iterables
         self.synchronize = synchronize
@@ -249,14 +250,6 @@ class Node(EngineBase):
         if hasattr(self._interface.inputs, 'num_threads'):
             self._interface.inputs.num_threads = self._n_procs
 
-    @property
-    def itername(self):
-        """Name for expanded iterable"""
-        itername = self._id
-        if self._hierarchy:
-            itername = '%s.%s' % (self._hierarchy, self._id)
-        return itername
-
     def output_dir(self):
         """Return the location of the output directory for the node"""
         # Output dir is cached
@@ -275,7 +268,7 @@ class Node(EngineBase):
                 params_str = [_parameterization_dir(p) for p in params_str]
             outputdir = op.join(outputdir, *params_str)
 
-        self._output_dir = op.abspath(op.join(outputdir, self.name))
+        self._output_dir = op.realpath(op.join(outputdir, self.name))
         return self._output_dir
 
     def set_input(self, parameter, val):
@@ -665,7 +658,8 @@ class Node(EngineBase):
 
     def _copyfiles_to_wd(self, execute=True, linksonly=False):
         """copy files over and change the inputs"""
-        if not hasattr(self._interface, '_get_filecopy_info'):
+        filecopy_info = get_filecopy_info(self.interface)
+        if not filecopy_info:
             # Nothing to be done
             return
 
@@ -678,7 +672,7 @@ class Node(EngineBase):
             outdir = op.join(outdir, '_tempinput')
             makedirs(outdir, exist_ok=True)
 
-        for info in self._interface._get_filecopy_info():
+        for info in filecopy_info:
             files = self.inputs.trait_get().get(info['key'])
             if not isdefined(files) or not files:
                 continue
